1.7.0
=====

We're happy to announce the release of numpydoc 1.7.0!

Enhancements
------------

- PERF: wrap inspect.getsourcelines with cache (`#532 <https://github.com/numpy/numpydoc/pull/532>`_).

Bug Fixes
---------

- during tokenize, use UTF8 encoding on all platforms (`#510 <https://github.com/numpy/numpydoc/pull/510>`_).
- fix 'Alias for field number X' problem with NamedTuples (`#527 <https://github.com/numpy/numpydoc/pull/527>`_).

Documentation
-------------

- DOC: Fix typos found by codespell (`#514 <https://github.com/numpy/numpydoc/pull/514>`_).
- DOC: Update link to mailing list (`#518 <https://github.com/numpy/numpydoc/pull/518>`_).
- Add Python 3.12 to classifiers (`#529 <https://github.com/numpy/numpydoc/pull/529>`_).
- Update release process (`#534 <https://github.com/numpy/numpydoc/pull/534>`_).
- Update release process (`#535 <https://github.com/numpy/numpydoc/pull/535>`_).

Maintenance
-----------

- [pre-commit.ci] pre-commit autoupdate (`#508 <https://github.com/numpy/numpydoc/pull/508>`_).
- [pre-commit.ci] pre-commit autoupdate (`#513 <https://github.com/numpy/numpydoc/pull/513>`_).
- MAINT: apply refurb suggestion (`#515 <https://github.com/numpy/numpydoc/pull/515>`_).
- [pre-commit.ci] pre-commit autoupdate (`#516 <https://github.com/numpy/numpydoc/pull/516>`_).
- Bump actions/setup-python from 4 to 5 (`#520 <https://github.com/numpy/numpydoc/pull/520>`_).
- [pre-commit.ci] pre-commit autoupdate (`#521 <https://github.com/numpy/numpydoc/pull/521>`_).
- Filter ``DeprecationWarning`` in failing test for python 3.12 (`#523 <https://github.com/numpy/numpydoc/pull/523>`_).
- MAINT: Replace NameConstant with Constant (`#524 <https://github.com/numpy/numpydoc/pull/524>`_).
- [pre-commit.ci] pre-commit autoupdate (`#526 <https://github.com/numpy/numpydoc/pull/526>`_).
- Update precommit repos (`#531 <https://github.com/numpy/numpydoc/pull/531>`_).
- Require sphinx 6 (`#530 <https://github.com/numpy/numpydoc/pull/530>`_).
- Use trusted publisher (`#533 <https://github.com/numpy/numpydoc/pull/533>`_).

Contributors
------------

8 authors added to this release (alphabetically):

- Chiara Marmo (`@cmarmo <https://github.com/cmarmo>`_)
- Daniel McCloy (`@drammock <https://github.com/drammock>`_)
- Dimitri Papadopoulos Orfanos (`@DimitriPapadopoulos <https://github.com/DimitriPapadopoulos>`_)
- Eric Larson (`@larsoner <https://github.com/larsoner>`_)
- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)
- Niko Föhr (`@fohrloop <https://github.com/fohrloop>`_)
- Philipp Hoffmann (`@dontgoto <https://github.com/dontgoto>`_)
- Ross Barnowski (`@rossbar <https://github.com/rossbar>`_)

9 reviewers added to this release (alphabetically):

- Antoine Pitrou (`@pitrou <https://github.com/pitrou>`_)
- Charles Harris (`@charris <https://github.com/charris>`_)
- Daniel McCloy (`@drammock <https://github.com/drammock>`_)
- Eric Larson (`@larsoner <https://github.com/larsoner>`_)
- GitHub Web Flow (`@web-flow <https://github.com/web-flow>`_)
- Jarrod Millman (`@jarrodmillman <https://github.com/jarrodmillman>`_)
- Niko Föhr (`@fohrloop <https://github.com/fohrloop>`_)
- Ross Barnowski (`@rossbar <https://github.com/rossbar>`_)
- Stefan van der Walt (`@stefanv <https://github.com/stefanv>`_)

_These lists are automatically generated, and may not be complete or may contain duplicates._
